===========
Algotel
===========

You can find here the companion notebooks that describe
the experiments of the paper submitted to Algotel 2023.

.. toctree::

    termination
    corsorts
    profiles
